flutter_miracl_sdk library

Classes

ActivationTokenErrorResponse
The response returned from activation token retrieval methods (e.g., MIRACLTrust.getActivationTokenByURI, MIRACLTrust.getActivationTokenByUserIdAndCode) when there is an issue with the verification confirmation.
ActivationTokenResponse
Response object returned from either the MIRACLTrust.getActivationTokenByURI or MIRACLTrust.getActivationTokenByUserIdAndCode methods.
AuthenticationSessionDetails
An object representing details from an incoming authentication session.
Configuration
The Configuration class is used to set up the MIRACL Trust Flutter Plugin.
EmailVerificationResponse
Response object returned from the MIRACLTrust.sendVerificationEmail method.
Logger
A type representing a message logger.
MIRACLTrust
The entry point of the MIRACL Trust Flutter Plugin.
QuickCode
An object representing a QuickCode and its validity period.
Signature
Represents the components of a MIRACL Trust cryptographic signature.
SigningResult
The result returned by the MIRACLTrust.sign method.
User
An object representing the user in the platform.

Enums

ActivationTokenExceptionCode
An enumeration that describes email verification issues.
AuthenticationExceptionCode
An enumeration that describes authentication issues.
AuthenticationSessionDetailsExceptionCode
An enumeration that describes authentication session management issues.
ConfigurationExceptionCode
An enumeration that describes issues with the SDK configuration.
EmailVerificationExceptionCode
An enumeration that describes email verification issues.
EmailVerificationMethod
Possible email verification methods.
IdentityType
Possible identity types that can be used for identity verification.
LoggingLevel
Defines the different levels of verbosity for the MIRACL Trust Flutter plugin's default logger.
QuickCodeExceptionCode
An enumeration that describes QuickCode generation issues.
RegistrationExceptionCode
An enumeration that describes registration issues.
SigningExceptionCode
An enumeration that describes signing issues.
VerificationMethod
Possible verification methods that can be used for identity verification.

Exceptions / Errors

ActivationTokenException
An exception thrown when there is an issue with the verification confirmation.
AuthenticationException
An exception thrown when there is an issue with the authentication.
AuthenticationSessionDetailsException
An exception thrown when there is an issue with the authentication session management.
ConfigurationException
An exception thrown when there is an issue with the SDK configuration.
EmailVerificationException
An exception thrown when there is an issue with the email verification.
QuickCodeException
An exception thrown when there is an issue with the QuickCode generation.
RegistrationException
An exception thrown when there is an issue with the registration.
SigningException
An exception thrown when there is an issue with the signing.