ActivationTokenExceptionCode enum

An enumeration that describes email verification issues.

Inheritance
Available extensions

Values

emptyUserId → const ActivationTokenExceptionCode

An empty User ID.

emptyVerificationCode → const ActivationTokenExceptionCode

An empty verification code.

unsuccessfulVerification → const ActivationTokenExceptionCode

An invalid or expired verification code. There may be ActivationTokenErrorResponse in the error.

getActivationTokenFail → const ActivationTokenExceptionCode

The request for fetching the activation token failed.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ActivationTokenExceptionCode>
A constant List of the values in this enum, in order of their declaration.