AuthenticationExceptionCode enum

An enumeration that describes authentication issues.

Inheritance
Available extensions

Values

invalidUserData → const AuthenticationExceptionCode

The user object passed for authentication is not valid.

invalidQRCode → const AuthenticationExceptionCode

Could not find the session identifier in the QR URL.

invalidPushNotificationPayload → const AuthenticationExceptionCode

Could not find a valid projectID, qrURL, or userID in the push notification payload.

userNotFound → const AuthenticationExceptionCode

There isn't a registered user for the provided User ID and project in the push notification payload.

Could not find the session identifier in the link.

authenticationFail → const AuthenticationExceptionCode

Authentication failed.

revoked → const AuthenticationExceptionCode

The user registration has been revoked due to too many unsuccessful authentication attempts or prolonged inactivity. The device must be re-registered.

invalidAuthenticationSession → const AuthenticationExceptionCode

An invalid or expired authentication session.

unsuccessfulAuthentication → const AuthenticationExceptionCode

The authentication was not successful.

pinCancelled → const AuthenticationExceptionCode

PIN not entered.

invalidPin → const AuthenticationExceptionCode

The PIN code includes invalid symbols or the PIN length does not match.

invalidCrossDeviceSession → const AuthenticationExceptionCode

Invalid or expired cross-device session.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthenticationExceptionCode>
A constant List of the values in this enum, in order of their declaration.