AuthenticationSessionDetailsException class

An exception thrown when there is an issue with the authentication session management.

Implemented types
Annotations
  • @Deprecated("Switch to the new CrossDeviceSession APIs.")

Properties

code AuthenticationSessionDetailsExceptionCode
The specific AuthenticationSessionDetailsExceptionCode indicating the type of error.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
underlyingError String?
An optional, human-readable message providing more details about the error.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited