AuthenticationSessionDetailsExceptionCode enum

An enumeration that describes authentication session management issues.

Inheritance
  • Object
  • Enum
  • AuthenticationSessionDetailsExceptionCode
Available extensions
Annotations
  • @Deprecated("Switch to the new CrossDeviceSession APIs.")

Values

Could not find the session identifier in the link.

invalidQRCode → const AuthenticationSessionDetailsExceptionCode

Could not find the session identifier in the QR code.

invalidNotificationPayload → const AuthenticationSessionDetailsExceptionCode

Could not find the session identifier in the push notification payload.

invalidAuthenticationSessionDetails → const AuthenticationSessionDetailsExceptionCode

The session identifier in AuthenticationSessionDetails is empty or blank.

getAuthenticationSessionDetailsFail → const AuthenticationSessionDetailsExceptionCode

Fetching the authentication session details failed.

abortSessionFail → const AuthenticationSessionDetailsExceptionCode

The abort of the authentication session has failed.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuthenticationSessionDetailsExceptionCode>
A constant List of the values in this enum, in order of their declaration.