ConfigurationException class

An exception thrown when there is an issue with the SDK configuration.

Implemented types

Properties

code ConfigurationExceptionCode
The specific ConfigurationExceptionCode indicating the type of configuration error.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited