CrossDeviceSessionExceptionCode enum

An enumeration that describes cross-device session management issues.

Inheritance
Available extensions

Values

Could not find the session identifier in the link.

invalidQRCode → const CrossDeviceSessionExceptionCode

Could not find the session identifier in the QR code.

invalidNotificationPayload → const CrossDeviceSessionExceptionCode

Could not find the session identifier in the push notification payload.

invalidCrossDeviceSession → const CrossDeviceSessionExceptionCode

The session identifier in the CrossDeviceSession is empty or blank.

getCrossDeviceSessionFail → const CrossDeviceSessionExceptionCode

Fetching the cross-device session details failed.

abortCrossDeviceSessionFail → const CrossDeviceSessionExceptionCode

Cross-device session abort failed.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CrossDeviceSessionExceptionCode>
A constant List of the values in this enum, in order of their declaration.