backoff property
The Unix timestamp indicating the earliest time a new verification email can be sent for the same User ID.
Implementation
final int backoff;
The Unix timestamp indicating the earliest time a new verification email can be sent for the same User ID.
final int backoff;