IdentityType enum
Possible identity types that can be used for identity verification.
Values
- email → const IdentityType
-
Identity is identified with email.
- alphanumeric → const IdentityType
-
Identity is identified with alphanumeric symbols.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getIdentityType(
String name) → IdentityType -
Returns the IdentityType corresponding to the given string
name.
Constants
-
values
→ const List<
IdentityType> - A constant List of the values in this enum, in order of their declaration.