LoggingLevel enum

Defines the different levels of verbosity for the MIRACL Trust Flutter plugin's default logger.

Note: It has no effect if a custom Logger implementation is provided.

Inheritance
Available extensions

Values

none → const LoggingLevel

No logs will be outputted.

error → const LoggingLevel

Only error-level logs will be outputted.

warning → const LoggingLevel

Error and warning logs will be outputted.

info → const LoggingLevel

Error, warning, and informational logs will be outputted.

debug → const LoggingLevel

All logs, including debug-level information, will be outputted.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LoggingLevel>
A constant List of the values in this enum, in order of their declaration.