MIRACLTrust class

The entry point of the MIRACL Trust Flutter Plugin.

Constructors

MIRACLTrust()
Provides access to the singleton instance of the MIRACL Trust Flutter Plugin.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

authenticate(User user, String pin) Future<String>
Authenticates a user to the MIRACL Trust platform by generating a JWT authentication token.
Authenticates a user in the MIRACL Trust platform via a link.
authenticateWithNotificationPayload(Map<String, String> payload, String pin) Future<void>
Authenticates a user in the MIRACL Trust platform via push notification.
authenticateWithQRCode(User user, String qrCode, String pin) Future<void>
Authenticates a user in the MIRACL Trust platform via QR code.
delete(User user) Future<void>
Deletes a registered user from the device.
generateQuickCode(User user, String pin) Future<QuickCode>
Generates a QuickCode for a registered user.
getActivationTokenByURI(Uri uri) Future<ActivationTokenResponse>
Confirms user verification and as a result, an activation token is obtained.
getActivationTokenByUserIdAndCode(String userId, String code) Future<ActivationTokenResponse>
Confirms user verification and as a result, an activation token is obtained.
Gets AuthenticationSessionDetails from the MIRACL Trust platform using a deep link.
getAuthenticationSessionDetailsFromPushNofitifactionPayload(Map<String, String> payload) Future<AuthenticationSessionDetails>
Gets AuthenticationSessionDetails from the MIRACL Trust platform using a push notification.
getAuthenticationSessionDetailsFromQRCode(String qrCode) Future<AuthenticationSessionDetails>
Gets AuthenticationSessionDetails from the MIRACL Trust platform using a QR code.
getUser(String userId) Future<User?>
Finds a registered user by their userId.
getUsers() Future<List<User>>
Retrieves the registered users, returning a list of User objects.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(String userId, String activationToken, String pin, [String? pushToken]) Future<User>
Provides end-user registration.
sendVerificationEmail(String userId) Future<EmailVerificationResponse>
Sends an email for User ID verification.
setProjectId(String projectId) Future<void>
Reconfigures the MIRACL Trust Flutter Plugin with a new project ID.
sign(User user, Uint8List message, String pin) Future<SigningResult>
Creates a cryptographic signature for a given document hash.
toString() String
A string representation of this object.
inherited
updateProjectSettings(String projectId, String projectUrl) Future<void>
Configures new project settings when the MIRACL Trust Flutter Plugin have to work with a different project.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

initialize(Configuration configuration) Future<void>
Configures the MIRACL Trust Flutter Plugin via the configuration object.