QuickCode class

An object representing a QuickCode and its validity period.

Properties

code String
The issued QuickCode.
final
expiryTime int
The MIRACL Trust system time when this QuickCode will expire.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttlSeconds int
The expiration period in seconds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited