QuickCodeExceptionCode enum
An enumeration that describes QuickCode generation issues.
Values
- revoked → const QuickCodeExceptionCode
-
The user registration has been revoked due to too many unsuccessful authentication attempts or prolonged inactivity. The device must be re-registered.
- unsuccessfulAuthentication → const QuickCodeExceptionCode
-
The authentication was not successful.
- pinCancelled → const QuickCodeExceptionCode
-
PIN not entered.
- invalidPin → const QuickCodeExceptionCode
-
The PIN code includes invalid symbols or the PIN length does not match.
- generationFail → const QuickCodeExceptionCode
-
The
QuickCodegeneration failed.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
QuickCodeExceptionCode> - A constant List of the values in this enum, in order of their declaration.