RegistrationExceptionCode enum
An enumeration that describes registration issues.
Values
- emptyUserId → const RegistrationExceptionCode
-
An empty User ID.
- emptyActivationToken → const RegistrationExceptionCode
-
An empty activation token.
- invalidActivationToken → const RegistrationExceptionCode
-
An invalid activation token.
- registrationFail → const RegistrationExceptionCode
-
The registration failed.
- unsupportedEllipticCurve → const RegistrationExceptionCode
-
The curve returned by the platform is unsupported by this version of the SDK.
- pinCancelled → const RegistrationExceptionCode
-
PIN not entered.
- invalidPin → const RegistrationExceptionCode
-
The PIN code includes invalid symbols or the PIN length does not match.
- projectMismatch → const RegistrationExceptionCode
-
The registration was started for a different project.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RegistrationExceptionCode> - A constant List of the values in this enum, in order of their declaration.