Signature class

Represents the components of a MIRACL Trust cryptographic signature.

Properties

dtas String
final
hash String
final
hashCode int
The hash code for this object.
no setterinherited
mpinId String
final
publicKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
u String
final
v String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited