SigningExceptionCode enum

An enumeration that describes signing issues.

Inheritance
Available extensions

Values

emptyMessageHash → const SigningExceptionCode

Empty message hash.

emptyPublicKey → const SigningExceptionCode

The public key of the signing identity is empty.

invalidUserData → const SigningExceptionCode

The user object passed for signing is not valid.

pinCancelled → const SigningExceptionCode

PIN not entered.

invalidPin → const SigningExceptionCode

The PIN code includes invalid symbols or the PIN length does not match.

signingFail → const SigningExceptionCode

The signing failed.

revoked → const SigningExceptionCode

The user registration has been revoked due to too many unsuccessful authentication attempts or prolonged inactivity. The device must be re-registered.

unsuccessfulAuthentication → const SigningExceptionCode

The authentication was not successful.

invalidSigningSession → const SigningExceptionCode

The signing session is invalid or has expired.

invalidSigningSessionDetails → const SigningExceptionCode

The session identifier in SigningSessionDetails is empty or blank.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SigningExceptionCode>
A constant List of the values in this enum, in order of their declaration.