ActivationTokenResponse class
Response object returned from either the MIRACLTrust.getActivationTokenByURI or MIRACLTrust.getActivationTokenByUserIdAndCode methods.
Properties
- accessId → String?
-
The identifier of the session from which the verification started.
final
- activationToken → String
-
The activation token returned after successful user verification.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectId → String
-
The identifier of the project against which the verification is performed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
The identifier of the user that is currently verified.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited