AuthenticationSessionDetails class
An object representing details from an incoming authentication session.
- Annotations
-
- @Deprecated("Switch to the new CrossDeviceSession APIs.")
Properties
- accessId → String
-
The identifier of the authentication session.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identityType → IdentityType
-
The IdentityType which will be used for identity verification.
final
- identityTypeLabel → String
-
Label of the identity which will be used for identity verification.
final
- pinLength → int
-
The required length (number of digits) for the user's PIN.
final
- projectId → String
-
The Project ID setting for the application in the MIRACL Trust platform.
final
- projectLogoURL → String
-
The URL of the project logo.
final
- projectName → String
-
The name of the project in the MIRACL Trust platform.
final
- quickCodeEnabled → bool
-
Indicates whether
QuickCodeis enabled for the project.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
The User ID entered by the user when the session is started.
final
- verificationCustomText → String
-
Custom text specified in the MIRACL Trust portal for the
custom verification.
final
- verificationMethod → VerificationMethod
-
Indicates the method of user verification.
final
- verificationURL → String
-
The URL for verification in case a custom verification method is used.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited