CrossDeviceSession class
An object representing details for an operation (authentication or signing) started on another device.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectId → String
-
The Project ID setting for the application in the MIRACL Trust platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionDescription → String
-
The description of the operation that needs to be done.
final
- sessionId → String
-
The identifier of the session.
final
- signingHash → String
-
The hash of the transaction that needs to be signed, if any.
final
- type → CrossDeviceSessionType
-
The type of the session.
no setter
- userId → String
-
The User ID entered by the user when the session is started.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited