EmailVerificationException class
An exception thrown when there is an issue with the email verification.
- Implemented types
Properties
- backoff → int?
-
A Unix timestamp before a new verification email can be sent for the same User ID.
final
- code → EmailVerificationExceptionCode
-
The specific EmailVerificationExceptionCode indicating the type of error.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- underlyingError → String?
-
An optional string representation of the underlying error, if any.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited