Logger class abstract
A type representing a message logger.
Some important and useful information from the native Android and iOS SDKs will be outputted through this interface, particularly during development and debugging.
By default, the MIRACL Trust Flutter plugin uses a concrete implementation of this interface using dart:developer library log function.
See also:
Constructors
- Logger()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debug(
String category, String message) → void -
Writes a
debuglevel log. -
error(
String category, String message) → void -
Writes an
errorlevel log. -
info(
String category, String message) → void -
Writes an
infolevel log. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
warning(
String category, String message) → void -
Writes a
warninglevel log.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited