User class
An object representing the user in the platform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hashedMpinId → String
-
Hex encoded SHA256 representation of the mpinId property.
final
- pinLength → int
-
The number of digits in the user's PIN.
final
- projectId → String
-
The Project ID setting for the application in the MIRACL Trust platform.
final
- revoked → bool
-
Whether the user is revoked.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
The identifier of the end user - an email, username, etc.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited